@@ -9,17 +9,19 @@ import win32event
 import servicemanager
 import socket
 from pystray import Icon, Menu, MenuItem
-
+from PIL import Image
 from axya_whisper.main import main
+from axya_whisper.upgrade import upgrade_and_restart_service
 
-print("HMMMM...")
 
 class HelloWindowService(win32serviceutil.ServiceFramework):
     _svc_name_ = 'AxyaWhisperService'
     _svc_display_name_ = 'Axya Genius Whisper'
+    _svc_description_ = "A service to sync the GeniusERP with Axya."
+    _svc_start_type_ = win32service.SERVICE_AUTO_START
+
 
     def __init__(self, args):
-        print("Running AxyaWhisper for Genius ERP")
         win32serviceutil.ServiceFramework.__init__(self, args)
         self.hWaitStop = win32event.CreateEvent(None, 0, 0, None)
         self.icon = None
@@ -38,13 +40,33 @@ class HelloWindowService(win32serviceutil.ServiceFramework):
 
     def create_system_tray_icon(self):
        menu = Menu(MenuItem('Exit', self.on_exit))
-       icon = Icon("MyIcon", "axya.ico", menu=menu)
+       script_dir = os.path.dirname(os.path.abspath(__file__))
+       icon_path = os.path.join(script_dir, "assets/axya.ico")
+       image = Image.open(icon_path)
+       icon = Icon("MyIcon", image, menu=menu)
        icon.run()
        return icon
     
     def on_exit(self, icon, item):
        icon.stop()
 
+
+    def check_environment_variables(self):
+        required_variables = [
+            'GENIUS_API_URL',
+            'GENIUS_API_LOGIN',
+            'GENIUS_API_PASSWORD',
+            'GENIUS_API_COMPANY_CODE',
+            'AXYA_API_URL',
+            'AXYA_API_TOKEN',
+        ]
+
+        for variable in required_variables:
+            if not os.environ.get(variable):
+                print(f"Environment variable {variable} is not set. Please set it and restart the service.")
+                win32serviceutil.StopService(self._svc_name_)
+                sys.exit(1)
+        
     def run_service(self):
         self.icon = self.create_system_tray_icon()
         while True:
@@ -54,6 +76,9 @@ class HelloWindowService(win32serviceutil.ServiceFramework):
                 else:
                     print("Getting here")
                     try:
+                        print("checking for updates...")
+                        upgrade_and_restart_service(self._svc_name_)
+                        print("Running main...")
                         main()
                     except Exception as e:
                         print(f"Error running main: {e}")
@@ -63,4 +88,3 @@ class HelloWindowService(win32serviceutil.ServiceFramework):
             except Exception as e:
                 servicemanager.LogErrorMsg(str(e))
                 time.sleep(300)
-
